#!/bin/bash -e

CMSIS_VERSION=9fe411cef1cef5de58e5957b89760759de44e393
CMSIS_SVD_VERSION=df75ff974c76a911fc2815e29807f5ecaae06fc2

if [ -e "cmsis-${CMSIS_VERSION}-clean.tar.xz" ]; then
echo "Not downloading cmsis-${CMSIS_VERSION}-clean.tar.xz again!"
else
# The license for this tarball is complicated, but the headers are under the
# BSD-3-Clause license, so we only package them.
wget -nc https://github.com/ARM-software/CMSIS/archive/${CMSIS_VERSION}/cmsis-${CMSIS_VERSION}.tar.gz
tar xf cmsis-${CMSIS_VERSION}.tar.gz
tar cJf cmsis-${CMSIS_VERSION}-clean.tar.xz \
    CMSIS-${CMSIS_VERSION}/README.md \
    CMSIS-${CMSIS_VERSION}/CMSIS/Include/
rm -r CMSIS-${CMSIS_VERSION}/
fi

if [ -e "cmsis_svd-${CMSIS_SVD_VERSION}-clean.tar.xz" ]; then
echo "Not downloading cmsis_svd-${CMSIS_SVD_VERSION}-clean.tar.xz again!"
else
# This is basically a "collection of random stuff" from various vendors, under
# various licenses. Some licenses are non-free and some are actively hostile,
# but we only need a rather small portion under a good license:
# - Atmel: Apache-2.0 AND BSD-Source-Code
# - Espressif: Apache-2.0
# - Espressif-Community: Apache-2.0 OR MIT
# - Kendryte-Community: ISC
# - NXP/L*: Proprietary, so not included.
# - NXP/M*: BSD-3-Clause
# - RaspberryPi: BSD-3-Clause
# - SiFive-Community: ISC
# - STMicro: Proprietary, so not included.
# These directories are not used by TinyGo, so are not kept:
# - ARM_SAMPLE: BSD-3-Clause
# - Cypress: Apache-2.0
# - Freescale: Proprietary
# - Fujitsu: Proprietary
# - Holtek: Proprietary
# - Nordic: BSD-3-Clause
# - Nuvoton: Unknown
# - SiliconLabs: Unknown
# - Spansion: Proprietary
# - TexasInstruments: Proprietary
# - Toshiba: Unknown
#wget https://github.com/posborne/cmsis-svd/archive/${CMSIS_SVD_VERSION}/cmsis_svd-${CMSIS_SVD_VERSION}.tar.gz
wget -nc https://github.com/tinygo-org/cmsis-svd/archive/${CMSIS_SVD_VERSION}/cmsis_svd-${CMSIS_SVD_VERSION}.tar.gz
tar xf cmsis_svd-${CMSIS_SVD_VERSION}.tar.gz
tar cJf cmsis_svd-${CMSIS_SVD_VERSION}-clean.tar.xz \
    cmsis-svd-${CMSIS_SVD_VERSION}/data/Atmel/ \
    cmsis-svd-${CMSIS_SVD_VERSION}/data/Espressif/ \
    cmsis-svd-${CMSIS_SVD_VERSION}/data/Espressif-Community/ \
    cmsis-svd-${CMSIS_SVD_VERSION}/data/Kendryte-Community/ \
    cmsis-svd-${CMSIS_SVD_VERSION}/data/NXP/M* \
    cmsis-svd-${CMSIS_SVD_VERSION}/data/RaspberryPi/ \
    cmsis-svd-${CMSIS_SVD_VERSION}/data/SiFive-Community/
rm -r cmsis-svd-${CMSIS_SVD_VERSION}/
fi
